# -*- coding: utf-8 -*-
"""
Project Name: zyt_auto_tools
File Created: 2023.12.31
Author: ZhangYuetao
File Name: auto_init_python_file.py
Update: 2025.06.06
"""

import os
import argparse
from datetime import datetime


def create_py_file(file_name, author, target_dir=None):
    """
    创建一个 .py 文件，并填充初始内容

    :param file_name: 要创建的文件名（包括 .py 后缀）
    :param author: 作者名
    :param target_dir: 目标文件夹路径（可选，默认为当前目录）
    """
    new_dir = False
    
    # 检查文件名是否以 .py 结尾，如果没有则自动添加
    if not file_name.endswith(".py"):
        file_name += ".py"

    # 如果没有指定目标文件夹，则使用当前目录
    if target_dir is None:
        target_dir = os.getcwd()
    else:
        # 如果目标文件夹不存在，则初始化创建python文件夹
        if not os.path.exists(target_dir):
            os.makedirs(target_dir)
            if file_name != "__init__.py":
                new_dir = True

    # 获取当前工作目录的名称作为项目名称
    project_name = os.path.basename(os.getcwd())

    # 获取当前日期
    current_date = datetime.now().strftime("%Y.%m.%d")

    # 初始内容模板
    content = f"""# -*- coding: utf-8 -*-
\"""
Project Name: {project_name}
File Created: {current_date}
Author: {author}
File Name: {file_name}
Update: {current_date}
\"""
"""

    # 拼接目标文件路径
    file_path = os.path.join(target_dir, file_name)

    # 创建文件并写入内容
    with open(file_path, 'w', encoding='utf-8') as file:
        file.write(content)

    print(f"文件 '{file_path}' 创建成功！")
    
    return new_dir


def main():
    # 创建 ArgumentParser 对象
    parser = argparse.ArgumentParser(description="自动初始化创建一个 .py 文件，并填充初始内容")

    # 从环境变量中读取默认作者名，如果未设置则使用 'ZhangYuetao'
    default_author = os.getenv("DEFAULT_AUTHOR", "ZhangYuetao")

    # 添加命令行参数
    parser.add_argument("file_name", type=str, 
                        help="要创建的文件名（包括 .py 后缀）")
    parser.add_argument("-a", "--author", type=str, default=default_author,
                        help="作者名（默认为环境变量 DEFAULT_AUTHOR 或 'ZhangYuetao'）")
    parser.add_argument("-d", "--dir", type=str, default=None, 
                        help="目标文件夹路径（可选，默认为当前目录）")

    # 解析命令行参数
    args = parser.parse_args()

    # 调用函数创建文件
    new_dir = create_py_file(args.file_name, args.author, args.dir)
    if new_dir:
        create_py_file("__init__.py", args.author, args.dir)


if __name__ == "__main__":
    main()



# -*- coding: utf-8 -*-
"""
Project Name: zyt_auto_tools
File Created: 2025.01.26
Author: ZhangYuetao
File Name: auto_create_structure.py
Update: 2025.01.26
"""

import os
import argparse
import fnmatch
import sys
from pathlib import Path

# 默认忽略的目录和文件
DEFAULT_IGNORES = {
    # Python 相关
    '__pycache__', '*.pyc', '*.pyo', '*.pyd', '*.pyi',
    '*.egg-info', '*.dist-info', 'build', 'dist', 'site-packages',

    # 版本控制
    '.git', '.svn', '.hg', '.bzr', '.gitmodules',

    # IDE 和编辑器
    '.idea', '.vscode', '.vs', '.history', '.project', '.classpath',
    '.metadata', '.recommenders', '.ropeproject',

    # 虚拟环境
    'venv', 'env', '.env', 'virtualenv', 'conda', 'pipenv', 'poetry',

    # 包管理
    'node_modules', 'bower_components', 'jspm_packages', 'package-lock.json',
    'yarn.lock', 'pnpm-lock.yaml', 'requirements.txt', 'Pipfile', 'Pipfile.lock',

    # 构建工具
    'target', 'out', 'bin', 'obj', 'build', 'dist', 'lib', 'lib64', 'include',

    # 日志和缓存
    'logs', 'log', '*.log', '*.tmp', '*.bak', '*.swp', '*.swo', '*.swn',
    '*.cache', '*.class', '*.jar', '*.war', '*.ear',

    # 操作系统
    '.DS_Store', 'Thumbs.db', 'desktop.ini', '.Spotlight-V100', '.Trashes',
    '.fseventsd', '.VolumeIcon.icns', '.apdisk',

    # 其他
    '.mypy_cache', '.pytest_cache', '.coverage', '.tox', '.hypothesis',
    '.ipynb_checkpoints', '.jupyter', '.spyderproject', '.spyproject',
    '.ropeproject', '.vscode-test', '.vscode-server', '.vscode-remote',
    '.vscode-insiders', '.vscode-exploration', '.vscode-oss',
}


def load_gitignore(directory):
    """从项目目录加载 .gitignore 文件并返回忽略规则集合"""
    gitignore_path = Path(directory) / '.gitignore'
    if not gitignore_path.is_file():
        return set()

    ignore_patterns = set()
    with open(gitignore_path, 'r', encoding='utf-8') as f:
        for line in f:
            line = line.strip()
            # 忽略空行和注释
            if line and not line.startswith('#'):
                ignore_patterns.add(line)
    return ignore_patterns


def is_ignored(name, ignore_patterns):
    """检查文件或目录是否匹配忽略模式"""
    for pattern in ignore_patterns:
        if fnmatch.fnmatch(name, pattern):
            return True
    return False


def generate_text_tree(directory, output_file=None, ignore_patterns=None, use_gitignore=False):
    """生成文本结构树"""
    # 如果启用 use_gitignore，则替换默认忽略列表
    if use_gitignore:
        ignore_patterns = load_gitignore(directory) | (ignore_patterns or set())
    else:
        # 否则使用默认忽略列表和用户指定的忽略列表
        ignore_patterns = DEFAULT_IGNORES | (ignore_patterns or set())

    tree = []

    def build_tree(path, prefix=''):
        try:
            entries = sorted([
                e for e in os.listdir(path)
                if not is_ignored(e, ignore_patterns)
            ])
        except PermissionError:
            # 无权限访问时，添加提示，包含目录名称
            dirname = os.path.basename(path)
            tree.append(f"{prefix}└── **no_permission_dir（{dirname}）**/")
            return

        for index, entry in enumerate(entries):
            full_path = os.path.join(path, entry)
            is_last = index == len(entries) - 1

            if os.path.isdir(full_path):
                tree.append(f"{prefix}{'└── ' if is_last else '├── '}{entry}/")
                new_prefix = prefix + ('    ' if is_last else '│   ')
                build_tree(full_path, new_prefix)
            else:
                tree.append(f"{prefix}{'└── ' if is_last else '├── '}{entry}")

    tree.append(os.path.basename(directory) + '/')
    build_tree(directory)

    if output_file:
        with open(output_file, 'w', encoding='utf-8') as f:
            f.write('\n'.join(tree))
        print(f"✅ 文本结构图已保存至：{output_file}")
    else:
        print('\n'.join(tree))


def main():
    parser = argparse.ArgumentParser(description="自动生成项目结构图")
    parser.add_argument('-d', '--dir', default=os.getcwd(),
                        help="项目目录（默认当前目录）")
    parser.add_argument('-o', '--output',
                        help="输出文件路径（可选）")
    parser.add_argument('-i', '--ignore', nargs='+',
                        help="额外忽略的目录/文件（支持通配符，空格分隔）")
    parser.add_argument('--use-gitignore', action='store_true',
                        help="使用 .gitignore 文件中的规则替换默认忽略列表")

    args = parser.parse_args()

    try:
        generate_text_tree(
            args.dir,
            output_file=args.output,
            ignore_patterns=set(args.ignore) if args.ignore else None,
            use_gitignore=args.use_gitignore
        )
    except Exception as e:
        print(f"❌ 错误：{str(e)}")
        sys.exit(1)


if __name__ == "__main__":
    main()



# -*- coding: utf-8 -*-
"""
Project Name: zyt_auto_tools
File Created: 2025.01.02
Author: ZhangYuetao
File Name: auto_update_ctime.py
Update: 2025.01.07
"""

import os
import argparse
from datetime import datetime


def is_file_modified_today(file_path):
    """
    检查文件是否在今天被修改过。

    :param file_path: 文件路径
    :return: 如果文件在今天被修改过，返回 True；否则返回 False。
    """
    # 获取文件的最后修改时间
    mtime = os.path.getmtime(file_path)
    # 转换为日期对象
    mtime_date = datetime.fromtimestamp(mtime).date()
    # 获取今天的日期
    today_date = datetime.now().date()
    # 判断是否相同
    return mtime_date == today_date


def update_file_update_date(file_path):
    """
    更新文件中 `Update` 日期为今天的日期。

    :param file_path: 文件路径
    """
    with open(file_path, 'r', encoding='utf-8') as file:
        lines = file.readlines()

    # 检查文件开头是否符合要求
    if len(lines) >= 6 and lines[0].startswith("# -*- coding: utf-8 -*-") and lines[1].strip() == '"""':
        # 查找 `Update` 行
        for i, line in enumerate(lines):
            if line.strip().startswith("Update:"):
                # 更新 `Update` 日期为今天的日期
                today_date = datetime.now().strftime("%Y.%m.%d")
                lines[i] = f"Update: {today_date}\n"
                break

        # 将更新后的内容写回文件
        with open(file_path, 'w', encoding='utf-8') as file:
            file.writelines(lines)
        print(f"Updated: {file_path}")
    else:
        print(f"Skipped: {file_path} (不符合文件开头格式)")


def update_files_in_directory(directory):
    """
    遍历指定目录下的所有 `.py` 文件，并更新今天修改过的文件的 `Update` 日期。

    :param directory: 目录路径
    """
    for root, _, files in os.walk(directory):
        for file in files:
            if file.endswith(".py"):
                file_path = os.path.join(root, file)
                # 检查文件是否在今天被修改过
                if is_file_modified_today(file_path):
                    update_file_update_date(file_path)
                else:
                    print(f"Skipped: {file_path} (今天未修改)")


def main():
    # 创建 ArgumentParser 对象
    parser = argparse.ArgumentParser(description="自动修改各代码文件修改时间")

    # 添加命令行参数
    parser.add_argument("-d", "--dir", type=str, default=os.getcwd(), help="目标文件夹路径（可选，默认为当前目录）")

    # 解析命令行参数
    args = parser.parse_args()

    # 检查目录是否存在
    if not os.path.isdir(args.dir):
        print(f"错误：目录 '{args.dir}' 不存在！")
        return

    update_files_in_directory(args.dir)


if __name__ == "__main__":
    main()



# -*- coding: utf-8 -*-
"""
Project Name: zyt_auto_tools
File Created: 2025.06.06
Author: ZhangYuetao
File Name: auto_init_python_dir.py
Update: 2025.07.07
"""

import os
import argparse
from datetime import datetime
import importlib.resources as pkg_resources

import zyt_auto_tools.templates


def create_project_structure(author, project_type, target_dir=None):
    """
    创建项目结构（文件夹 + 多个初始化文件），每个文件先写入 base_header，再追加模板代码（如存在）

    :param author: 作者名
    :param project_type: 类型，可选 'software' 或 'crawler'
    :param target_dir: 项目路径，默认当前目录
    """

    if target_dir is None:
        target_dir = os.getcwd()

    os.makedirs(target_dir, exist_ok=True)

    # 获取当前工作目录的名称作为项目名称
    project_name = os.path.basename(os.getcwd())
    current_date = datetime.now().strftime("%Y.%m.%d")

    def base_header(filename):
        return f"""# -*- coding: utf-8 -*-
\"\"\"
Project Name: {project_name}
File Created: {current_date}
Author: {author}
File Name: {filename}
Update: {current_date}
\"\"\"
"""

    file_map = {
        "init": ["__init__.py"],
        "software": ["main.py", "config.py", "utils.py", 
                     os.path.join('settings', 'secret.toml'),os.path.join('settings', 'software_infos.toml'), os.path.join('settings', 'xey.ico'),
                     os.path.join('network', '__init__.py'), os.path.join('network', 'server_connect.py'), os.path.join('network', 'software_update.py'), 
                     os.path.join('ui', '__init__.py'), os.path.join('ui', 'feedback.py'), os.path.join('ui', 'feedback.ui'),
                     os.path.join('ui', 'main', '__init__.py'), os.path.join('ui', 'main', 'main_window.py'), os.path.join('ui', 'main', 'feedback_main.py')
                     ],
        "crawler": ["config.py", "logger.py", "start_crawler.py",
                    os.path.join('settings', 'basic_setting.toml'), os.path.join('settings', 'chrome_setting.toml'),
                    os.path.join('settings', 'lake', 'proxies.txt'), os.path.join('settings', 'lake', 'user_agents.txt'), 
                    os.path.join('settings', 'cookies', 'load_cookies.toml'),
                    os.path.join('spiders', '__init__.py'), os.path.join('spiders', 'example.py'),
                    os.path.join('utils', '__init__.py'), os.path.join('utils', 'generic_utils.py'), os.path.join('utils', 'log_utils.py'),
                    os.path.join('plugins', '__init__.py'), os.path.join('plugins', 'open_chrome.py'), os.path.join('plugins', 'proxy_test.py')
                    ],
        "spiders": ["proxy_test.py", "config.py", "utils.py", "start_crawler.py", "scrapy.cfg",
                    os.path.join('settings', 'basic_settings.toml'), 
                    os.path.join('settings', 'lake', 'proxies.txt'), os.path.join('settings', 'lake', 'user_agents.txt'),
                    os.path.join('web_spiders', '__init__.py'), os.path.join('web_spiders', 'items.py'), os.path.join('web_spiders', 'middlewares.py'),
                    os.path.join('web_spiders', 'pipelines.py'), os.path.join('web_spiders', 'settings.py'),
                    os.path.join('web_spiders', 'spiders', '__init__.py'), os.path.join('web_spiders', 'spiders', 'example.py')
                    ]
    }
    if project_type is None:
        project_type = "init"

    if project_type not in file_map:
        raise ValueError(f"未知项目类型: {project_type}")
    
    if target_dir:
        file_map[project_type].append("__init__.py")

    for filename in file_map[project_type]:
        file_path = os.path.join(target_dir, filename)
        
        os.makedirs(os.path.dirname(file_path), exist_ok=True)
        template_pkg = f"zyt_auto_tools.templates.{project_type}"
        template_file = filename + ".txt"

        # 构建最终文件内容
        content = base_header(os.path.basename(filename))
        
        if 'xey.ico' in filename:
            with pkg_resources.files(template_pkg).joinpath(template_file).open("rb") as tpl:
                template_content = tpl.read()
        else:
            with pkg_resources.files(template_pkg).joinpath(template_file).open("r", encoding="utf-8") as tpl:
                template_content = tpl.read()  
            content += template_content

        # 写入到文件中
        if file_path.endswith('.py'):
            with open(file_path, 'w', encoding='utf-8') as f:
                f.write(content)
        else:
            if 'xey.ico' in filename:
                with open(file_path, 'wb') as f:
                    f.write(template_content)
            else:
                if 'secret.toml' in filename:
                    file_path = file_path.replace('secret', '.secret')
                
                with open(file_path, 'w', encoding='utf-8') as f:
                    f.write(template_content)

        print(f"初始化文件 '{file_path}' 创建成功！")

    print(f"项目文件夹 '{target_dir}' 创建完成，类型：{project_type}")


def main():
    # 创建 ArgumentParser 对象
    parser = argparse.ArgumentParser(description="自动初始化创建python项目文件夹，并填充初始内容")

    # 从环境变量中读取默认作者名，如果未设置则使用 'ZhangYuetao'
    default_author = os.getenv("DEFAULT_AUTHOR", "ZhangYuetao")

    # 添加命令行参数
    parser.add_argument("-a", "--author", type=str, default=default_author,
                        help="作者名（默认为环境变量 DEFAULT_AUTHOR 或 'ZhangYuetao'）")
    parser.add_argument("-t", "--type", type=str, default=None, choices=[None, "software", "crawler", "spiders"],
                        help="项目类型：None（默认）表示单__init__.py文件的初始化python文件夹，software 表示软件项目，crawler 表示爬虫项目，spiders 表示爬虫项目(scrapy框架)")
    parser.add_argument("-d", "--dir", type=str, default=None, 
                        help="目标文件夹路径（可选，默认为当前目录）")
    
    # 解析命令行参数
    args = parser.parse_args()

    create_project_structure(args.author, args.type, args.dir)


if __name__ == "__main__":
    main()



# -*- coding: utf-8 -*-
"""
Project Name: zyt_auto_tools
File Created: 2025.01.02
Author: ZhangYuetao
File Name: setup.py
Update: 2025.07.07
"""

from setuptools import setup, find_packages

# 读取 README.md 文件内容作为长描述
with open("README.md", "r", encoding="utf-8") as f:
    long_description = f.read()

# noinspection PyInterpreter
setup(
    name="zyt_auto_tools",
    version="0.4.1",
    author="ZhangYuetao",
    author_email="zhang894171707@gmail.com",
    description="A collection of automation tools for Python projects",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/VerySeriousMan/zyt_auto_tools",
    packages=find_packages(),
    include_package_data=True,
    package_data={
        "zyt_auto_tools": [
            "templates/init/*.txt",
            "templates/software/*.txt",
            "templates/software/network/*.txt",
            "templates/software/ui/*.txt",
            "templates/software/ui/main/*.txt",
            "templates/software/settings/*.txt",
            "templates/crawler/*.txt",
            "templates/crawler/settings/*.txt",
            "templates/crawler/settings/lake/*.txt",
            "templates/crawler/settings/cookies/*.txt",
            "templates/crawler/spiders/*.txt",
            "templates/crawler/plugins/*.txt",
            "templates/crawler/utils/*.txt",
            "templates/spiders/*.txt",
            "templates/spiders/settings/*.txt",
            "templates/spiders/settings/lake/*.txt",
            "templates/spiders/web_spiders/*.txt",
            "templates/spiders/web_spiders/spiders/*.txt",
        ],
    },
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.6',
    install_requires=[],
    entry_points={
        "console_scripts": [
            "auto-generate-init=zyt_auto_tools.auto_generate_init:main",
            "auto-init-python-file=zyt_auto_tools.auto_init_python_file:main",
            "auto-update-ctime=zyt_auto_tools.auto_update_ctime:main",
            "auto-create-structure=zyt_auto_tools.auto_create_structure:main",
            "auto-init-python-dir=zyt_auto_tools.auto_init_python_dir:main",
        ],
    },
)



# -*- coding: utf-8 -*-
"""
Project Name: zyt_auto_tools
File Created: 2025.01.02
Author: ZhangYuetao
File Name: __init__.py
Update: 2025.06.06
"""

from .auto_generate_init import *
from .auto_init_python_file import *
from .auto_update_ctime import *
from .auto_create_structure import *
from .auto_init_python_dir import *
